@@ -987,8 +987,8 @@ class WordToken(models.Model):
         return True
 
     def getAnalysisLines(self,output_form):
-        form = output_form
-        wanted_lines = output_form.get_wanted_fields()
+        form = output_form.cleaned_data
+        wanted_fields = output_form.get_wanted_fields()
         if self.Output is not None:
             #outline = {x: self.Output[x] for x in self.Output if x not in form['force_fetch']}
             outline = copy.copy(self.Output)
