@@ -71,10 +71,13 @@ def doReset(logfilename):
     res.get()
 
 @task()
-def combineResults(allout):
+def combineResults(allout,wanted=None):
     if not os.path.isdir(fetch_media_resource("Results/Buckeye")):
         os.mkdir(fetch_media_resource("Results/Buckeye"))
-    head = allout[0][0].keys()
+    if wanted is None:
+        head = allout[0][0].keys()
+    else:
+        head = wanted
     with open(fetch_media_resource("Results/Buckeye/analysis.txt"),'w') as f:
         f.write("\t".join(head))
         f.write("\n")
@@ -109,7 +112,7 @@ def doBasicAnalysis(form):
         #    AnalyzeSpeaker.delay(s,form)
         #job = group([AnalyzeSpeaker.s(speaker, form) for speaker in sp])
         #job.apply_async(link=consolidateResultFiles.s())
-        res = chord((AnalyzeSpeaker.s(s, form) for s in sp), combineResults.s())()
+        res = chord((AnalyzeSpeaker.s(s, form.cleaned_data) for s in sp), combineResults.s(wanted=form.get_wanted_fields()))()
         res.get()
 
 @task()
